aboutsummaryrefslogtreecommitdiff
path: root/bpkg/pkg-verify.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'bpkg/pkg-verify.hxx')
-rw-r--r--bpkg/pkg-verify.hxx10
1 files changed, 6 insertions, 4 deletions
diff --git a/bpkg/pkg-verify.hxx b/bpkg/pkg-verify.hxx
index 907b37c..a772a8f 100644
--- a/bpkg/pkg-verify.hxx
+++ b/bpkg/pkg-verify.hxx
@@ -17,14 +17,16 @@ namespace bpkg
int
pkg_verify (const pkg_verify_options&, cli::scanner& args);
// Verify archive is a valid package and return its manifest. Throw
// failed if invalid or if something goes wrong. If diag is false,
// then don't issue diagnostics about the reason why the package is
// invalid.
//
package_manifest
pkg_verify (const common_options&,
const path& archive,
+ bool expand_values,
bool ignore_unknown,
bool diag = true);
@@ -17,14 +17,16 @@ namespace bpkg
int
pkg_verify (const pkg_verify_options&, cli::scanner& args);
- // Verify archive is a valid package and return its manifest. Throw
- // failed if invalid or if something goes wrong. If diag is false,
- // then don't issue diagnostics about the reason why the package is
- // invalid.
+ // Verify archive is a valid package and return its manifest. If requested,
+ // expand the file-referencing manifest values (description, changes, etc),
+ // setting them to the contents of files they refer to. Throw failed if
+ // invalid or if something goes wrong. If diag is false, then don't issue
+ // diagnostics about the reason why the package is invalid.
//
package_manifest